==> exit-options_23.8.tar.xz: BUILD/translations/exit-options_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="30"/>
        <source>Restart Fluxbox</source>
        <translation>Ponovno zaženi Fluxbox</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="32"/>
        <source>Lock Screen</source>
        <translation>Zakleni zaslon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="34"/>
        <source>Log Out</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="36"/>
        <source>Suspend</source>
        <translation>Zaustavitev</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="38"/>
        <source>Reboot</source>
        <translation>Ponovni zagon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Shutdown</source>
        <translation>Izklop</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <location filename="../main.cpp" line="51"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>Pojavno okno z možnostmi za izhod iz MX Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>Display buttons in a vertical window</source>
        <translation>Prikaži gumbe v navpičnem oknu</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Display buttons in a horizontal window</source>
        <translation>Prikaži gumbe v vodoravnem oknu</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Timeout duration in seconds</source>
        <translation>Časovna omejitev v sekundah</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>uporabite -v, -vertical za navpični prikaz gumbov
uporabite -h, -horizontal za vodoravni prikaz gumbov</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Usage: exit-options [options]
</source>
        <translation>Uporaba: exit-options [možnosti]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Options:</source>
        <translation>Možnosti:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>-h, -horizontal	 Vodoravni prikaz gumbov</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>-v, -vertical	 Navpični prikaz gumbov</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>-t, -timeout &lt;sec&gt;	Časovna omejitev v sekundah</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>Orientacija prikaza se bo shranila in bo uporabljena ob naslednjem zagonu aplikacije</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>Namesto tega lahko nastavite &quot;layout=horizontal&quot; ali &quot;layout=vertical&quot; v ~/.config/MX-Linux/exit-options.conf</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation>Za določitev čakalne časa v  exit-options.conf , uporabite &apos;timeout=X&apos;, kjer je čas čakalni čas v sekundah.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>Ikone lahko določite po meri z dodajanjem IconName=/pot/imeikone.ext v datoteko exit-options.conf. Ime ikon, ki jih premapirate: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>Druge možnosti, ki jih je možno določiti v datoteki exit-options.conf: %1</translation>
    </message>
</context>
</TS>

==> exit-options_24.3.tar.xz: BUILD/translations/exit-options_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="30"/>
        <source>Restart Fluxbox</source>
        <translation>Ponovno zaženi Fluxbox</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="32"/>
        <source>Lock Screen</source>
        <translation>Zakleni zaslon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="34"/>
        <source>Log Out</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="36"/>
        <source>Suspend</source>
        <translation>Zaustavitev</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="38"/>
        <source>Reboot</source>
        <translation>Ponovni zagon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Shutdown</source>
        <translation>Izklop</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <location filename="../main.cpp" line="51"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>Pojavno okno z možnostmi za izhod iz MX Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>Display buttons in a vertical window</source>
        <translation>Prikaži gumbe v navpičnem oknu</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Display buttons in a horizontal window</source>
        <translation>Prikaži gumbe v vodoravnem oknu</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Timeout duration in seconds</source>
        <translation>Časovna omejitev v sekundah</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>uporabite -v, -vertical za navpični prikaz gumbov
uporabite -h, -horizontal za vodoravni prikaz gumbov</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Usage: exit-options [options]
</source>
        <translation>Uporaba: exit-options [možnosti]</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Options:</source>
        <translation>Možnosti:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>-h, -horizontal	 Vodoravni prikaz gumbov</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>-v, -vertical	 Navpični prikaz gumbov</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>-t, -timeout &lt;sec&gt;	Časovna omejitev v sekundah</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>Orientacija prikaza se bo shranila in bo uporabljena ob naslednjem zagonu aplikacije</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>Namesto tega lahko nastavite &quot;layout=horizontal&quot; ali &quot;layout=vertical&quot; v ~/.config/MX-Linux/exit-options.conf</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation>Za določitev časovne omejitve v  exit-options.conf , uporabite &apos;timeout=X&apos;, kjer je X časovna omejitev v sekundah.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>Ikone lahko določite po meri z dodajanjem IconName=/pot/imeikone.ext v datoteko exit-options.conf. Ime ikon, ki jih premapirate: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>Druge možnosti, ki jih je možno določiti v datoteki exit-options.conf: %1</translation>
    </message>
</context>
</TS>
